@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2009-2019 Edgewall Software
+# Copyright (C) 2009-2020 Edgewall Software
 # All rights reserved.
 #
 # This software is licensed as described in the file COPYING, which
@@ -247,9 +247,9 @@ class TestAddUserToGroup(FunctionalTwillTestCaseSetup):
             tc.formvalue('addsubj', 'sg_group', 'authenticated')
             tc.submit()
             tc.find("The subject someuser was not added to the "
-                    "group authenticated because the group has "
-                    "TICKET_CHGPROP permission and users cannot "
-                    "grant permissions they don't possess.")
+                    "group authenticated. The group has TICKET_CHGPROP "
+                    "permission and you cannot grant permissions you "
+                    "don't possess.")
         finally:
             self._tester.login('admin')
             self._tester.go_to_admin("Permissions")
