@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2005-2019 Edgewall Software
+# Copyright (C) 2005-2020 Edgewall Software
 # Copyright (C) 2005 Jonas Borgström <jonas@edgewall.com>
 # All rights reserved.
 #
@@ -402,11 +402,11 @@ class PermissionAdminPanel(Component):
                     else:
                         req.perm.require(action,
                             message=_("The subject %(subject)s was not added "
-                                      "to the group %(group)s because the "
-                                      "group has %(perm)s permission and "
-                                      "users cannot grant permissions they "
-                                      "don't possess.", subject=subject,
-                                      group=group, perm=action))
+                                      "to the group %(group)s. The group has "
+                                      "%(perm)s permission and you cannot "
+                                      "grant permissions you don't possess.",
+                                      subject=subject, group=group,
+                                      perm=action))
                 if (subject, group) not in all_permissions:
                     perm.grant_permission(subject, group)
                     add_notice(req, _("The subject %(subject)s has been added "
