@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2019 Edgewall Software
+# Copyright (C) 2008-2020 Edgewall Software
 # All rights reserved.
 #
 # This software is licensed as described in the file COPYING, which
@@ -297,14 +297,26 @@ class RegressionTestTicket3663(FunctionalTwillTestCaseSetup):
 
         Verify that URLs not encoded with UTF-8 are reported as invalid.
         """
-        # invalid PATH_INFO
-        self._tester.go_to_wiki(u'été'.encode('latin1'))
-        tc.code(404)
-        tc.find('Invalid URL encoding')
-        # invalid SCRIPT_NAME
-        tc.go(u'été'.encode('latin1'))
-        tc.code(404)
-        tc.find('Invalid URL encoding')
+        import httplib
+        # Work around for InvalidURL since Python 2.7.17 (#13233)
+        saved_re = httplib._contains_disallowed_url_pchar_re \
+                   if hasattr(httplib, '_contains_disallowed_url_pchar_re') \
+                   else None
+        try:
+            if saved_re:
+                httplib._contains_disallowed_url_pchar_re = \
+                    re.compile(r'[\x00-\x20]')
+            # invalid PATH_INFO
+            self._tester.go_to_wiki(u'été'.encode('latin1'))
+            tc.code(404)
+            tc.find('Invalid URL encoding')
+            # invalid SCRIPT_NAME
+            tc.go(u'été'.encode('latin1'))
+            tc.code(404)
+            tc.find('Invalid URL encoding')
+        finally:
+            if saved_re:
+                httplib._contains_disallowed_url_pchar_re = saved_re
 
 
 class RegressionTestTicket6318(FunctionalTwillTestCaseSetup):
@@ -320,7 +332,6 @@ class RegressionTestTicket6318(FunctionalTwillTestCaseSetup):
         self._tester.logout()
         try:
             # also test a regular ascii user name
-            self._testenv.adduser(u'user')
             self._tester.login(u'user')
             self._tester.go_to_front()
             self._tester.logout()
