@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2003-2019 Edgewall Software
+# Copyright (C) 2003-2020 Edgewall Software
 # Copyright (C) 2003-2005 Daniel Lundin <daniel@edgewall.com>
 # Copyright (C) 2005-2006 Emmanuel Blot <emmanuel.blot@free.fr>
 # All rights reserved.
@@ -969,9 +969,9 @@ class TicketAttachmentNotifier(Component):
         try:
             NotificationSystem(self.env).notify(event)
         except Exception as e:
-            self.log.error("Failure sending notification when adding "
-                           "attachment %s to ticket #%s: %s",
-                           attachment.filename, ticket.id,
+            self.log.error("Failure sending notification when %s for "
+                           "attachment '%s' to ticket #%s: %s",
+                           category, attachment.filename, ticket.id,
                            exception_to_unicode(e))
 
 
