@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2004-2019 Edgewall Software
+# Copyright (C) 2004-2020 Edgewall Software
 # Copyright (C) 2004-2005 Christopher Lenz <cmlenz@gmx.de>
 # Copyright (C) 2005-2007 Christian Boos <cboos@edgewall.org>
 # All rights reserved.
@@ -33,7 +33,7 @@ from trac.resource import Resource
 from trac.ticket.api import TicketSystem, translation_deactivated
 from trac.ticket.model import Milestone, _datetime_to_db_str
 from trac.ticket.roadmap import group_milestones
-from trac.util import Ranges, as_bool
+from trac.util import Ranges, as_bool, as_int
 from trac.util.datefmt import (datetime_now, from_utimestamp,
                                format_date_or_datetime, parse_date,
                                to_timestamp, to_utimestamp, utc, user_time)
@@ -45,7 +45,7 @@ from trac.web.href import Href
 from trac.web.chrome import (INavigationContributor, Chrome,
                              add_ctxtnav, add_link, add_script,
                              add_script_data, add_stylesheet, add_warning,
-                             web_context)
+                             auth_link, web_context)
 from trac.wiki.api import IWikiSyntaxProvider
 from trac.wiki.formatter import MacroError
 from trac.wiki.macros import WikiMacroBase
@@ -934,7 +934,7 @@ class QueryModule(Component):
 
     def process_request(self, req):
         req.perm(self.realm).assert_permission('TICKET_VIEW')
-        report_id = req.args.getfirst('report')
+        report_id = req.args.as_int('report')
         if report_id:
             req.perm('report', report_id).assert_permission('REPORT_VIEW')
 
@@ -1015,9 +1015,12 @@ class QueryModule(Component):
         # Add registered converters
         for conversion in Mimeview(self.env) \
                           .get_supported_conversions('trac.ticket.Query'):
-            add_link(req, 'alternate',
-                     query.get_href(req.href, format=conversion.key),
-                     conversion.name, conversion.out_mimetype, conversion.key)
+            format_ = conversion.key
+            conversion_href = query.get_href(req.href, format=format_)
+            if format_ == 'rss':
+                conversion_href = auth_link(req, conversion_href)
+            add_link(req, 'alternate', conversion_href, conversion.name,
+                     conversion.out_mimetype, format_)
 
         if format:
             filename = 'query' if format != 'rss' else None
@@ -1159,10 +1162,11 @@ class QueryModule(Component):
             data['report_href'] = req.href.report()
             add_ctxtnav(req, _("Available Reports"), req.href.report())
             add_ctxtnav(req, _("New Custom Query"), req.href.query())
-            if query.id:
+            report_id = as_int(query.id, None)
+            if report_id is not None:
                 for title, description in self.env.db_query("""
                         SELECT title, description FROM report WHERE id=%s
-                        """, (query.id,)):
+                        """, (report_id,)):
                     data['report_resource'] = report_resource
                     data['description'] = description
         else:
@@ -1192,8 +1196,10 @@ class QueryModule(Component):
         return 'query.html', data, None
 
     def export_csv(self, req, query, sep=',', mimetype='text/plain'):
-        """:deprecated: since 1.0.6, use `_export_csv` instead. Will be
-                        removed in 1.3.1.
+        """Export as CSV
+
+        :deprecated: since 1.0.6, use `_export_csv` instead. Will be
+            removed in 1.3.1.
         """
         content, content_type = self._export_csv(req, query, sep, mimetype)
         return ''.join(content), content_type
@@ -1243,8 +1249,10 @@ class QueryModule(Component):
         return iterate(), '%s;charset=utf-8' % mimetype
 
     def export_rss(self, req, query):
-        """:deprecated: since 1.0.6, use `_export_rss` instead. Will be
-                        removed in 1.3.1.
+        """Export as RSS
+
+        :deprecated: since 1.0.6, use `_export_rss` instead. Will be
+            removed in 1.3.1.
         """
         content, content_type = self._export_rss(req, query)
         return ''.join(content), content_type
