@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2004-2019 Edgewall Software
+# Copyright (C) 2004-2020 Edgewall Software
 # All rights reserved.
 #
 # This software is licensed as described in the file COPYING, which
@@ -1384,6 +1384,19 @@ ORDER BY COALESCE(t.id,0)=0,t.id""".format(**quoted))
                          '%d,0\r\n' % (tktids[0], tktids[1]),
                          csv)
 
+    def test_rss_feed_for_authenticated_users(self):
+        req = MockRequest(self.env, authname='admin', path_info='/query',
+                          args={'status': '!closed'})
+        self._process_request(req)
+        alternates = req.chrome['links']['alternate']
+        for link in alternates:
+            if link['type'] == 'application/rss+xml':
+                break
+        else:
+            self.fail('No application/rss+xml in %r' % alternates)
+        self.assertIn('/trac.cgi/login?referer=%2Ftrac.cgi%2Fquery%3F',
+                      link['href'])
+
 
 class QueryLinksTestCase(unittest.TestCase):
 
@@ -1432,7 +1445,7 @@ class QueryLinksTestCase(unittest.TestCase):
     def test_duplicated_report_arguments(self):
         data = self._process_request('report=1&report=2')
         self.assertEqual([], data['tickets'])
-        self.assertEqual('1', data['query'].id)
+        self.assertEqual(1, data['query'].id)
 
     def test_duplicated_group_arguments(self):
         self._insert_ticket(status='new')
@@ -1473,6 +1486,16 @@ class QueryLinksTestCase(unittest.TestCase):
         self.assertTrue(data['query'].groupdesc)
         self.assertFalse(data['query'].desc)
 
+    def test_non_numeric_report_argument(self):
+        data = self._process_request('id=0&report=42xx')
+        self.assertEqual([], data['tickets'])
+        self.assertEqual(None, data['query'].id)
+
+    def test_unicode_report_argument(self):
+        data = self._process_request(u'id=0&report=42éá')
+        self.assertEqual([], data['tickets'])
+        self.assertEqual(None, data['query'].id)
+
 
 class TicketQueryMacroTestCase(unittest.TestCase):
 
