@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2003-2019 Edgewall Software
+# Copyright (C) 2003-2020 Edgewall Software
 # Copyright (C) 2003-2005 Jonas Borgström <jonas@edgewall.com>
 # All rights reserved.
 #
@@ -128,12 +128,12 @@ class TicketModule(Component):
     # IContentConverter methods
 
     def get_supported_conversions(self):
+        yield ('rss', _("RSS Feed"), 'xml',
+               'trac.ticket.Ticket', 'application/rss+xml', 8)
         yield ('csv', _("Comma-delimited Text"), 'csv',
                'trac.ticket.Ticket', 'text/csv', 8)
         yield ('tab', _("Tab-delimited Text"), 'tsv',
                'trac.ticket.Ticket', 'text/tab-separated-values', 8)
-        yield ('rss', _("RSS Feed"), 'xml',
-               'trac.ticket.Ticket', 'application/rss+xml', 8)
 
     def convert_content(self, req, mimetype, ticket, key):
         if key == 'csv':
@@ -1202,8 +1202,10 @@ class TicketModule(Component):
         return content.getvalue(), '%s;charset=utf-8' % mimetype
 
     def export_rss(self, req, ticket):
-        """:deprecated: since 1.0.6, use `_export_rss` instead. Will be
-                        removed in 1.3.1.
+        """Export as RSS
+
+        :deprecated: since 1.0.6, use `_export_rss` instead. Will be
+            removed in 1.3.1.
         """
         content, content_type = self._export_rss(req, ticket)
         return ''.join(content), content_type
