@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2003-2019 Edgewall Software
+# Copyright (C) 2003-2020 Edgewall Software
 # Copyright (C) 2003-2005 Jonas Borgström <jonas@edgewall.com>
 # Copyright (C) 2005-2006 Christian Boos <cboos@edgewall.org>
 # All rights reserved.
@@ -398,9 +398,10 @@ class LogModule(Component):
                     repos = rm.get_repository(reponame)
 
             if repos:
-                if 'LOG_VIEW' in formatter.perm(repos.resource):
+                path = path or '/'
+                if 'LOG_VIEW' in formatter.perm(repos.resource
+                                                .child('source', path)):
                     reponame = repos.reponame or None
-                    path = path or '/'
                     revranges = RevRanges(repos, revs)
                     if revranges.has_ranges():
                         href = formatter.href.log(reponame, path,
